@@ -1,3 +1,6 @@
+# Copyright 2021 UW-IT, University of Washington
+# SPDX-License-Identifier: Apache-2.0
+
 import json
 from urllib.parse import quote
 from restclients_core.exceptions import DataFailureException
@@ -28,3 +31,18 @@ def get_resource(url):
     if response.status != 200:
         raise DataFailureException(url, response.status, response.data)
     return json.loads(response.data)
+
+
+def put_resource(url, headers={}, body={}):
+    """
+    Issue a PUT request to SWS with the given url
+    and return a response in json format.
+    :returns: http response with content in json
+    """
+    headers['Accept'] = 'application/json'
+
+    response = DAO.putURL(url, headers, json.dumps(body))
+
+    if response.status != 200:
+        raise DataFailureException(url, response.status, response.data)
+    return json.loads(response.data)
