@@ -1,3 +1,6 @@
+# Copyright 2021 UW-IT, University of Washington
+# SPDX-License-Identifier: Apache-2.0
+
 from unittest import TestCase
 from uw_sws.util import fdao_sws_override
 from uw_pws.util import fdao_pws_override
@@ -20,12 +23,13 @@ class PersonTest(TestCase):
         self.assertEquals(data.first_name, "John Joseph")
         self.assertEquals(data.pronouns, "he/him/his")
         self.assertEquals(data.last_name, "Average")
-        self.assertEquals(data.student_name, "Average,John Joseph")
+        self.assertEquals(data.student_name, "John Joseph Average")
         self.assertEquals(data.student_number, "1033334")
         self.assertEquals(data.student_system_key, "000083856")
-        self.assertEquals(data.visa_type, None)
-        self.assertEquals(data.local_phone, None)
-        self.assertEquals(data.local_address.city, "Seattle")
+        self.assertEquals(data.visa_type, '')
+        self.assertFalse(data.is_veteran())
+        self.assertEquals(data.local_phone, '2063333333')
+        self.assertEquals(data.local_address.city, "SEATTLE")
         self.assertEquals(data.local_address.country, "United States")
         self.assertEquals(data.local_address.street_line1, "4634 26th Ave NE")
         self.assertEquals(data.local_address.street_line2, "APT 102")
@@ -33,7 +37,7 @@ class PersonTest(TestCase):
         self.assertEquals(data.local_address.state, "WA")
         self.assertEquals(data.local_address.zip_code, "98105")
 
-        self.assertEquals(data.permanent_phone, "4255556789")
+        self.assertEquals(data.permanent_phone, "2065555555")
         self.assertEquals(data.permanent_address.city, "Bellevue")
         self.assertEquals(data.permanent_address.country, "")
         self.assertEquals(data.permanent_address.street_line1,
