@@ -1,3 +1,6 @@
+# Copyright 2021 UW-IT, University of Washington
+# SPDX-License-Identifier: Apache-2.0
+
 from datetime import datetime, timedelta
 from unittest import TestCase
 from uw_sws.util import fdao_sws_override
@@ -711,9 +714,10 @@ class SWSTestSectionData(TestCase):
         self.assertEqual(person.display_name, 'PWS, FOUR OH FOUR')
 
     def test_remote_section(self):
+        # MUWM-4728, MUWM-4989
         section = get_section_by_label('2020,autumn,E E,233/A')
-        self.assertTrue(section.is_remote)
-        self.assertTrue(section.json_data()['is_remote'])
+        self.assertFalse(section.is_remote)
+        self.assertFalse(section.json_data()['is_remote'])
         self.assertTrue(section.is_source_sdb())
 
         self.assertTrue(is_remote({"Text": "OFFERED VIA REMOTE LEARNING"}))
